<?php

namespace Drupal\xray_audit\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Core\Render\RendererInterface;
use Drupal\xray_audit\Form\FlushCacheForm;
use Drupal\xray_audit\Services\PluginRepositoryInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Returns responses for the list of groups.
 */
final class XrayAuditHomeController extends ControllerBase {

  use XrayAuditBuildTaskItemsInControllerTrait;

  /**
   * Plugin repository.
   *
   * @var \Drupal\xray_audit\Services\PluginRepositoryInterface
   */
  protected $pluginRepository;

  /**
   * Renderer service.
   *
   * @var \Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * Constructs of Controller.
   *
   * @param \Drupal\xray_audit\Services\PluginRepositoryInterface $plugin_repository
   *   Plugin manager for Groups.
   * @param \Drupal\Core\Render\RendererInterface $renderer
   *   Service renderer.
   */
  public function __construct(PluginRepositoryInterface $plugin_repository, RendererInterface $renderer) {
    $this->pluginRepository = $plugin_repository;
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new self(
      $container->get('xray_audit.plugin_repository'),
      $container->get('renderer'),
    );
  }

  /**
   * Builds the home response.
   *
   * @return array
   *   Render array.
   */
  public function build(): array {
    $build = [];
    $groupDefinitions = $this->pluginRepository->getGroupPluginDefinitions();
    if (empty($groupDefinitions)) {
      return [];
    }
    usort($groupDefinitions, function ($a, $b) {
      return ($a['sort'] ?? 0) <=> ($b['sort'] ?? 0);
    });

    foreach ($groupDefinitions as $group_definition) {
      // The different tasks.
      $build[] = [
        '#theme' => 'admin_block',
        '#block' => [
          'title' => (string) $group_definition['label'],
          'content' => [
            '#theme' => 'admin_block_content',
            '#content' => $this->buildTaskItems($group_definition['id']),
          ],
          'description' => (string) $group_definition['description'],
        ],
      ];
    }

    $build['form'] = $this->formBuilder()->getForm(FlushCacheForm::class);

    return $build;
  }

}
